@@ -827,7 +827,7 @@ void FreeBusyManager::publishFreeBusy(QWidget *parentWidget)
 
     // We need to massage the list a bit so that Outlook understands
     // it.
-    messageText = messageText.replace(QRegExp(QStringLiteral("ORGANIZER\\s*:MAILTO:")),
+    messageText.replace(QRegExp(QStringLiteral("ORGANIZER\\s*:MAILTO:")),
                                       QStringLiteral("ORGANIZER:"));
 
     // Create a local temp file and save the message to it
@@ -861,7 +861,7 @@ void FreeBusyManager::publishFreeBusy(QWidget *parentWidget)
             QString fbname = CalendarSettings::self()->publishUserName();
             int at = fbname.indexOf('@');
             if (at > 1 && fbname.length() > (uint)at) {
-                fbname = fbname.left(at);
+                fbname.truncate(at);
             }
             targetURL.setPath("/freebusy/" + fbname + ".ifb");
             targetURL.setUserName(CalendarSettings::self()->publishUserName());
